Index: build/android/pylib/linker/test_runner.py |
diff --git a/build/android/pylib/linker/test_runner.py b/build/android/pylib/linker/test_runner.py |
index a0b486017c0ef51d4ac911ff143170d38ec1e96e..3b4ee5cb3d0023353c65c40e5b7ce46b3cc02b1c 100644 |
--- a/build/android/pylib/linker/test_runner.py |
+++ b/build/android/pylib/linker/test_runner.py |
@@ -80,14 +80,14 @@ class LinkerTestRunner(base_test_runner.BaseTestRunner): |
"""Sets up and runs a test case. |
Args: |
test: An object which is ostensibly a subclass of LinkerTestCase. |
Returns: |
A TestRunResults object which contains the result produced by the test |
and, in the case of a failure, the test that should be retried. |
""" |
- assert isinstance(test, test_case.LinkerTestCase) |
+ assert isinstance(test, test_case.LinkerTestCaseBase) |
try: |
results = test.Run(self.device) |
@@ -80,14 +80,14 @@ class LinkerTestRunner(base_test_runner.BaseTestRunner): |
"""Sets up and runs a test case. |
Args: |
- test: An object which is ostensibly a subclass of LinkerTestCase. |
+ test: An object which is ostensibly a subclass of LinkerTestCaseBase. |
Returns: |
A TestRunResults object which contains the result produced by the test |